@@ -31,13 +31,11 @@
 #include <stdarg.h>
 #include <ctype.h>
 #include <string.h>
+#include <errno.h>
 
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
-#ifdef HAVE_ERRNO_H
-# include <errno.h>
-#endif
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>		/* select() */
 #endif
@@ -66,6 +64,7 @@
 #include "error.h"
 #include "getpass.h"
 #include "getaddrinfo.h"
+#include "quote.h"
 
 /* Get i18n. */
 #include <gettext.h>
